summaryrefslogtreecommitdiffstats
path: root/kio/kio/chmodjob.h
diff options
context:
space:
mode:
Diffstat (limited to 'kio/kio/chmodjob.h')
-rw-r--r--kio/kio/chmodjob.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/kio/kio/chmodjob.h b/kio/kio/chmodjob.h
index fdb873b17..d1fe572f9 100644
--- a/kio/kio/chmodjob.h
+++ b/kio/kio/chmodjob.h
@@ -42,7 +42,7 @@ namespace KIO {
/**
* Create new ChmodJobs using the KIO::chmod() function.
*/
- ChmodJob( const KFileItemList & lstItems, int permissions, int mask,
+ ChmodJob( const KFileItemList & lstItems, int permissions, int tqmask,
int newOwner, int newGroup,
bool recursive, bool showProgressInfo );
@@ -63,7 +63,7 @@ namespace KIO {
};
enum { STATE_LISTING, STATE_CHMODING } state;
int m_permissions;
- int m_mask;
+ int m_tqmask;
int m_newOwner;
int m_newGroup;
bool m_recursive;
@@ -91,8 +91,8 @@ namespace KIO {
*
* @param lstItems The file items representing several files or directories.
* @param permissions the permissions we want to set
* @param mask the bits we are allowed to change.
* For instance, if mask is 0077, we don't change
* the "user" bits, only "group" and "others".
* @param newOwner If non-empty, the new owner for the files
* @param newGroup If non-empty, the new group for the files
@@ -100,7 +100,7 @@ namespace KIO {
* @param showProgressInfo true to show progess information
* @return The job handling the operation.
*/
- KIO_EXPORT ChmodJob * chmod( const KFileItemList& lstItems, int permissions, int mask,
+ KIO_EXPORT ChmodJob * chmod( const KFileItemList& lstItems, int permissions, int tqmask,
TQString newOwner, TQString newGroup,
bool recursive, bool showProgressInfo = true );
@@ -91,8 +91,8 @@ namespace KIO {
* @param lstItems The file items representing several files or directories.
* @param permissions the permissions we want to set
- * @param mask the bits we are allowed to change.
- * For instance, if mask is 0077, we don't change
+ * @param tqmask the bits we are allowed to change.
+ * For instance, if tqmask is 0077, we don't change
* the "user" bits, only "group" and "others".
* @param newOwner If non-empty, the new owner for the files